@@ -26,10 +26,18 @@ class Stream:
         def on_open(ws):
             self.__websocket = ws
 
+        def on_error(ws, *args):
+            print('ws err', *args)
+
+        def on_close(ws, *args):
+            print('ws close', *args)
+
         ws = websocket.WebSocketApp(
             self.url,
             on_message=self.__on_message,
             on_open=on_open,
+            on_error=on_error,
+            on_close=on_close,
         )
         self.__thread = threading.Thread(target=ws.run_forever, args=())
         self.__thread.start()
@@ -43,7 +51,7 @@ class Stream:
     def join(self):
         self.__thread.join()
 
-    def subscribe(self, obj_id: str, event: str, cb: Callable[[Any], None], specials=True, payload=False) -> str:
+    def subscribe(self, obj_id, event, cb, specials=True, payload=False):
         id = new_id()
 
         sub = {}
